pub enum RuleId {
UndefinedVariable,
UndefinedGlobal,
UndefinedField,
UnusedVariable,
}Expand description
Unique identifier for each lint rule.
Variants
UndefinedVariable
Reference to a variable not defined in any enclosing scope.
UndefinedGlobal
Reference to a global name not in the known symbol table.
UndefinedField
Access to a field not declared in a ---@class definition.
UnusedVariable
A local variable that is declared but never referenced.